@@ -27,7 +27,11 @@ def upload_static_file(path):
 
 def upload_file(path):
     dh = DriverHelper()
-    x = dh.upload_file_auto("studio-loop-link", [path])
+    x = dh.upload_file_auto("studio-result", [path])
+    return x[0].split(";;")[-1]
+def upload_file_resource(path):
+    dh = DriverHelper()
+    x = dh.upload_file_auto("studio", [path])
     return x[0].split(";;")[-1]
 def remove(path):
     try:
