@@ -179,7 +179,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
                     rs.close()
                     vidPathTmp = FFmpeg.add_null_sound(comp.video_path)
                     rs = VideoFileClip(vidPathTmp)
-                rs.write_videofile(introPath, bitrate='4M', fps=24, codec='libx264', audio=False)
+                rs.write_videofile(introPath, bitrate='4M', fps=24, codec='libx264', audio_bitrate='128000')
                 is_cont = True
                 rs.close()
             if comp.is_outro:
@@ -189,7 +189,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
                     rs.close()
                     vidPathTmp = FFmpeg.add_null_sound(comp.video_path)
                     rs = VideoFileClip(vidPathTmp)
-                rs.write_videofile(outroPath, bitrate='4M', fps=24, codec='libx264', audio=False)
+                rs.write_videofile(outroPath, bitrate='4M', fps=24, codec='libx264', audio_bitrate='128000')
                 is_cont = True
                 rs.close()
             if is_cont:
